kecpkg-tools
============

.. image:: https://img.shields.io/pypi/v/kecpkg-tools.svg
    :target: https://pypi.python.org/pypi/kecpkg-tools
    :alt: Version

.. image:: https://img.shields.io/pypi/pyversions/kecpkg-tools.svg
    :target: https://pypi.python.org/pypi/kecpkg-tools
    :alt: Supported Python Versions

.. image:: https://travis-ci.org/KE-works/kecpkg-tools.svg?branch=master
    :target: https://travis-ci.org/KE-works/kecpkg-tools
    :alt: Build Status

.. image:: https://badges.gitter.im/KE-works/pykechain.svg
   :alt: Join the chat at https://gitter.im/KE-works/pykechain
   :target: https://gitter.im/KE-works/pykechain?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge

.. contents:: **Table of Contents**
    :backlinks: none

Usage
-----

`kecpkg-tools` provide a set of tools to easily create KE-chain packages. These
are executable python scripts aimed for execution on the KE-chain SIM platform.

It requires normal user access to a `KE-chain <http://www.ke-chain.com>`__ instance for it to work.
KE-chain is the flexible engineering platform of `KE-works <http://www.ke-works.com>`__.

See Also
--------

KE-chain packages for SIM are used in combination with `pykechain <https://github.com/KE-works/pykechain>`__,
the open source KE-chain python api.

Installation
------------

`kecpkg-tools` is distributed on `PyPI <https://pypi.org>`_ as a universal
wheel and is available on Linux/macOS and Windows and supports
Python 2.7/3.5+ and PyPy.

.. code-block:: bash

    $ pip install kecpkg-tools

License
-------

kecpkg-tools is distributed under the terms of the
`Apache License, Version 2.0 <https://choosealicense.com/licenses/apache-2.0>`_.
